@@ -19,8 +19,8 @@
       record /epPos/ pp
 
       call epDraw_torus0(comp, p, n)
-      if( comp.struc == "torus_y" .or. 
-     *    comp.struc == "torus_x"  ) then
+      if( comp.struc(1:7) == "torus_y" .or. 
+     *    comp.struc(1:7) == "torus_x"  ) then
          do i = 1, n
             if( p(i).x /= gpsep )   then
                call epc2v_torus(comp, p(i), pp)
