@@ -1,5 +1,5 @@
 #!/bin/bash
-work=/tmp/$USER/Work
+work=Work
 if [ $#  -lt  5 ] || [ $# -gt 7 ]; then
     cat <<EOF
     Usage: ./testPairSamp.sh  media events E1 E2 step [LPMeffect func]
@@ -58,7 +58,7 @@ echo $nevent $Eg $media $LPMeffect  |  ./a.out  | awk '{print $2}' | histo     0
 
   echo "Eg=${Eg}" > $work/gnuplot.com
 
-  cat pair.gp | awk '{gsub(/WWW/,this);print}' this=$work  >> $work/gnuplot.com
+  cat pair.gp >> $work/gnuplot.com
 
   echo  set output  \"$work/pair${f}.png\" >>$work/gnuplot.com
   echo  rep  >>$work/gnuplot.com
