@@ -1,7 +1,7 @@
-!        
+c        
       common /BPgene/ media, Eeme, Egme
       common /BPgeneC/ force
-       type(epmedia)::   media
+      record /epmedia/  media
       real*8 Eeme, Egme
       character(8):: force
 
