@@ -56,7 +56,14 @@
 #else
     real(8),parameter::sq3=sqrt(3.d0)
 #endif
-    complex(kind(0d0)),parameter::w(3) = (/(1.d0,0.d0), (-1.0d0,sq3)/2.d0, (-1.0d0, -sq3)/2.d0 /)
+!!          the last (-1.0d0, -sq3)/2.d0 
+!!   leads to error @ jaxa Fujitsu compiler; message is
+!!   stragne; right parentheis is missing... 
+!!   real reason :  -sq3 is NG.
+!!   same notation for non complex is OK.
+!!    complex(kind(0d0)),parameter::w(3) = (/(1.d0,0.d0), (-1.0d0,sq3)/2.d0, (-1.0d0, -sq3)/2.d0 /)
+!!         next is workaround.  
+    complex(kind(0d0)),parameter::w(3) = (/(1.d0,0.d0), (-1.0d0,sq3)/2.d0, -(1.0d0, sq3)/2.d0 /)
 
     complex(kind(0d0))::u(3), v(3), uu, vv
     complex(kind(0d0))::D
