@@ -1,22 +1,22 @@
-!
-!        horse:                                  top view
-!                                         Y     _______
-!               side view                  | * |       | \
-!              ------------                _*_ |       |____\_
-!             /            \               |   |       | b'  |
-!      h     /              \              |   |x0_____|     |
-!           /                \             |  *    a'    \   | b
-!          /                  \            | *           \   |
-!         ---------------------            |*_______________\|  --> X
-!                                                 a
-!     
-!      a: side length of the lower square >= 0
-!      b: side length of  //           >=0  
-!      h: hight  > 0
-!   x0,y0: upper square origin
-!     a': side length of the upper square   a'>=0
-!     b': side length of the upper square   b'>=0.  (a=b=a'=b'=0 is not
-!                                                    allowed)
+c
+c        horse:                                  top view
+c                                         Y     _______
+c               side view                  | * |       | \
+c              ------------                _*_ |       |____\_
+c             /            \               |   |       | b'  |
+c      h     /              \              |   |x0_____|     |
+c           /                \             |  *    a'    \   | b
+c          /                  \            | *           \   |
+c         ---------------------            |*_______________\|  --> X
+c                                                 a
+c     
+c      a: side length of the lower square >= 0
+c      b: side length of  //           >=0  
+c      h: hight  > 0
+c   x0,y0: upper square origin
+c     a': side length of the upper square   a'>=0
+c     b': side length of the upper square   b'>=0.  (a=b=a'=b'=0 is not
+c                                                    allowed)
       subroutine kxplhorse(a, b, h, x0, y0, ap, bp, 
      *                    pos, dir, length, icon, face)
        implicit none
@@ -28,8 +28,8 @@
 #include "Zepdebug.h"
 
        real(8),intent(in):: a, b, h, x0, y0,  ap, bp  ! input homrse param.
-       type(epPos)::  pos   ! input.  position.
-       type(epDirec)::  dir  ! input. direction cosinse
+       record /epPos/ pos   ! input.  position.
+       record /epDirec/ dir  ! input. direction cosinse
 
        real(8),intent(out)::  length !  output length cm from pos to the boundary
        integer,intent(out)::icon  ! output 0: length obtained. pos    is inside
@@ -42,17 +42,17 @@
 
        integer:: np, jcon
        
-       type(epPos):: p1, p2, p3, p4
+       record /epPos/p1, p2, p3, p4
 
        real(8):: l, xpa(2)
        integer::  facea(2)
        np = 0
        if(a > 0. .and. b > 0.) then
-!              bottom 
+c              bottom 
           p1 = epPos(0.d0, 0.d0, 0.d0)
           p2 = epPos(a, 0.d0, 0.d0)
-          p3 = epPos(p2%x, b, 0.d0)
-          p4 = epPos(0.d0, p3%y, 0.d0)
+          p3 = epPos(p2.x, b, 0.d0)
+          p4 = epPos(0.d0, p3.y, 0.d0)
           call epxpLand4vp(p1, p2, p3, p4, pos, dir, l, icon, jcon)
           if(icon .le. 4 .and. l>0.) then
              np = np +1
@@ -62,11 +62,11 @@
        endif
 
        if(ap  > 0. .and. bp > 0.) then
-!            top
+c            top
           p1 = epPos(x0, y0, h)
           p2 = epPos(x0+ap, y0, h)
-          p3 = epPos(p2%x, y0+bp, h)
-          p4 = epPos(x0, p3%y, h)
+          p3 = epPos(p2.x, y0+bp, h)
+          p4 = epPos(x0, p3.y, h)
           call epxpLand4vp(p1, p2, p3, p4, pos, dir, l, icon, jcon)
 
           if(icon .le. 4 .and. l > 0.) then
@@ -76,7 +76,7 @@
           endif
           if(np .eq. 2) goto 100
        endif
-!           side x-z 1       
+c           side x-z 1       
        p1 = epPos(0.d0, 0.d0, 0.d0)
        p2 = epPos(a, 0.d0, 0.d0)
        p3 = epPos(x0+ap, y0, h)
@@ -90,7 +90,7 @@
        endif
        if(np .eq. 2) goto 100
 
-!           side x-z 2
+c           side x-z 2
        p1 = epPos( 0.d0, b, 0.d0)
        p2 = epPos( x0, y0+bp, h)
        p3 = epPos(x0+ap, y0+bp, h)
@@ -103,7 +103,7 @@
           facea(np) = 4
        endif
        if(np .eq. 2) goto 100
-!           y-z 1       
+c           y-z 1       
        p1 = epPos(0.d0, 0.d0, 0.d0)
        p2 = epPos(x0, y0, h)
        p3 = epPos(x0, y0+bp, h)
@@ -116,7 +116,7 @@
           facea(np) = 5
        endif
        if(np .eq. 2) goto 100
-!           y-z 2
+c           y-z 2
        p1 = epPos(a, 0.d0, 0.d0)
        p2 = epPos(a, b, 0.d0)
        p3 = epPos(x0+ap, y0+bp, h)
@@ -155,7 +155,7 @@
           length = xpa(1)
           face = facea(1)
        else
-!           not cross with the volume
+c           not cross with the volume
           icon = -1
        endif
 
