@@ -30,6 +30,7 @@ c           fpolygon  has height and npoly vertex  attributes and the direction
 c           of the 'x' and 'y'==> (1-6)
 c
       integer i,  j
+      character(len=MAX_STRUCCHR):: basename 
 c             next is mandatory
       call eprpst(comp, 0, 0, 1, 6)
       call epfpolygonCnst(comp)  ! this call, xmin etc  in Volat
@@ -52,12 +53,8 @@ c             next is mandatory
       Volat( j+1 ) = ymin
       Volat( j+2 ) = xmax
       Volat( j+3 ) = ymax
-
-      if( comp.struc == 'fpolygon' .or.
-     *    comp.struc == 'fpolygon_xy'     ) then
-      elseif( comp.struc == 'fpolygon_yz' ) then
-      elseif( comp.struc == 'fpolygon_zx' ) then
-      else
+      call epGetBaseStrucName(comp.struc, basename)
+      if( basename /= 'fpolygon' ) then
          write(0,*) 'structure=',comp.struc, ' not usable'
          stop
       endif
@@ -547,14 +544,15 @@ c
       record /epPos/ temp
 
       call epfpolygonCnst(comp)
-      if( comp.struc  == 'fpolygon' ) then
+      if( comp.struc  == 'fpolygon' .or. 
+     *    comp.struc  == 'fpolygon_w' ) then
          posc = posv
-      elseif( comp.struc  == 'fpolygon_xy' ) then
+      elseif( comp.struc(1:11)  == 'fpolygon_xy' ) then
          posc = posv
-      elseif( comp.struc == "fpolygon_yz" ) then
+      elseif( comp.struc(1:11) == "fpolygon_yz" ) then
          temp =epPos(posv.y, posv.z, posv.x)
          posc = temp
-      elseif( comp.struc == "fpolygon_zx" ) then
+      elseif( comp.struc(1:11) == "fpolygon_zx" ) then
          temp = epPos( posv.z, posv.x, posv.y)
          posc = temp 
       else
@@ -580,16 +578,17 @@ c
       record /epPos/ temp    !
 
       call epfpolygonCnst(comp)
-      if( comp.struc  == 'fpolygon' ) then
+      if( comp.struc  == 'fpolygon' .or.
+     *    comp.struc  == 'fpolygon_w'  ) then
          posv = posc
-      elseif( comp.struc  == 'fpolygon_xy' ) then
+      elseif( comp.struc(1:11)  == 'fpolygon_xy' ) then
          posv = posc
-      elseif( comp.struc == "fpolygon_yz" ) then
+      elseif( comp.struc(1:11) == "fpolygon_yz" ) then
 !                X:y   Y:z    Z:x
          temp = epPos( posc.z, posc.x, posc.y)
 !!         posc = temp !!!!!!!!!!!! aho
          posv = temp
-      elseif( comp.struc == "fpolygon_zx" ) then
+      elseif( comp.struc(1:11) == "fpolygon_zx" ) then
 !         cpos = epPos( pos.z, pos.x, pos.y)
 !                  X:z    Y:x          Z:y
          temp = epPos(posc.y, posc.z, posc.x)
@@ -616,14 +615,15 @@ c
      
       call epfpolygonCnst(comp)
 
-      if( comp.struc  == 'fpolygon' ) then
+      if( comp.struc  == 'fpolygon' .or.
+     *    comp.struc  == 'fpolygon_w' ) then
          dirc = dirv
-      elseif( comp.struc  == 'fpolygon_xy' ) then
+      elseif( comp.struc(1:11)  == 'fpolygon_xy' ) then
          dirc = dirv
-      elseif( comp.struc == "fpolygon_yz" ) then
+      elseif( comp.struc(1:11) == "fpolygon_yz" ) then
          temp = epDirec(dirv.y, dirv.z, dirv.x)
          dirc = temp
-      elseif( comp.struc == "fpolygon_zx" ) then
+      elseif( comp.struc(1:11) == "fpolygon_zx" ) then
          temp = epDirec(dirv.z, dirv.x, dirv.y)
          dirc = temp
       else
@@ -648,15 +648,16 @@ c
 
       call epfpolygonCnst(comp)
 !           (X,Y,Z)<---(x,y,z)
-      if( comp.struc  == 'fpolygon' ) then
+      if( comp.struc  == 'fpolygon' .or.
+     *    comp.struc  == 'fpolygon_w') then
          dirv = dirc
-      elseif( comp.struc  == 'fpolygon_xy' ) then
+      elseif( comp.struc(1:11)  == 'fpolygon_xy' ) then
          dirv = dirc
-      elseif( comp.struc == "fpolygon_yz" ) then
+      elseif( comp.struc(1:11) == "fpolygon_yz" ) then
 !         cdir = epDirec(dir.y, dir.z, dir.x)  X:y  Y:z  Z:x
          temp = epDirec(dirc.z, dirc.x, dirc.y) 
          dirv = temp   
-      elseif( comp.struc  == 'fpolygon_zx' ) then
+      elseif( comp.struc(1:11)  == 'fpolygon_zx' ) then
 !         cdir = epDirec(dir.z, dir.x, dir.y)  X:z Y:x Z:y
          temp = epDirec(dirc.y, dirc.z, dirc.x) 
          dirv = temp
