@@ -1239,14 +1239,15 @@ c         Compnum = comp.cn
       record /epPos/ temp
 
       call ep_honeycmCnst(comp)
-      if( comp.struc  == 'honeycomb' ) then
+      if( comp.struc  == 'honeycomb' .or.
+     *    comp.struc  == 'honeycomb_w'  ) then
          posc = posv
-      elseif( comp.struc  == 'honeycomb_xy' ) then
+      elseif( comp.struc(1:12)  == 'honeycomb_xy' ) then
          posc = posv
-      elseif( comp.struc == "honeycomb_yz" ) then
+      elseif( comp.struc(1:12) == "honeycomb_yz" ) then
          temp =epPos(posv.y, posv.z, posv.x)
          posc = temp
-      elseif( comp.struc == "honeycomb_zx" ) then
+      elseif( comp.struc(1:12) == "honeycomb_zx" ) then
          temp = epPos( posv.z, posv.x, posv.y)
          posc = temp
 !      elseif( comp.struc == "honeycomb_x" ) then
@@ -1275,15 +1276,16 @@ c         Compnum = comp.cn
       record /epPos/ temp
 
       call ep_honeycmCnst(comp)
-      if( comp.struc  == 'honeycomb' ) then
+      if( comp.struc  == 'honeycomb' .or.
+     *    comp.struc  == 'honeycomb_w'  ) then
          posv = posc
-      elseif( comp.struc  == 'honeycomb_xy' ) then
+      elseif( comp.struc(1:12)  == 'honeycomb_xy' ) then
          posv = posc
-      elseif( comp.struc == "honeycomb_yz" ) then
+      elseif( comp.struc(1:12) == "honeycomb_yz" ) then
 !                yzx:  y<->x   z<->y  x<->z
          temp = epPos( posc.z, posc.x, posc.y)
          posv = temp
-      elseif( comp.struc == "honeycomb_zx" ) then
+      elseif( comp.struc(1:12) == "honeycomb_zx" ) then
 !            zxy 
          temp= epPos(posc.y, posc.z, posc.x)
          posv = temp
@@ -1307,15 +1309,16 @@ c         Compnum = comp.cn
       record /epDirec/ temp
 
       call ep_honeycmCnst(comp)
-      if( comp.struc  == 'honeycomb' ) then
+      if( comp.struc  == 'honeycomb' .or.
+     *    comp.struc  == 'honeycomb_w'  ) then
          dirc = dirv
-      elseif( comp.struc  == 'honeycomb_xy' ) then
+      elseif( comp.struc(1:12)  == 'honeycomb_xy' ) then
          dirc = dirv
-      elseif( comp.struc == "honeycomb_yz" ) then
+      elseif( comp.struc(1:12) == "honeycomb_yz" ) then
 !          yzx
          temp = epDirec(dirv.y, dirv.z, dirv.x)
          dirc = temp
-      elseif( comp.struc == "honeycomb_zx" ) then
+      elseif( comp.struc(1:12) == "honeycomb_zx" ) then
          temp = epDirec(dirv.z, dirv.x, dirv.y)
          dirc = temp
 !      elseif( comp.struc == "honeycomb_x" ) then
@@ -1344,16 +1347,17 @@ c         Compnum = comp.cn
       record /epDirec/ temp
       call ep_honeycmCnst(comp)
 !     (X,Y,Z)<---(x,y,z)
-      if( comp.struc  == 'honeycomb' ) then
+      if( comp.struc  == 'honeycomb' .or.
+     *    comp.struc  == 'honeycomb_w' ) then
          dirv = dirc
-      elseif( comp.struc  == 'honeycomb_xy' ) then
+      elseif( comp.struc(1:12)  == 'honeycomb_xy' ) then
          dirv = dirc
-      elseif( comp.struc == "honeycomb_yz" ) then
+      elseif( comp.struc(1:12) == "honeycomb_yz" ) then
 !         cdir = epDirec(dir.y, dir.z, dir.x)  X:y  Y:z  Z:x
 !                 yzx
          temp = epDirec(dirc.z, dirc.x, dirc.y)
          dirv = temp
-      elseif( comp.struc  == 'honeycomb_zx' ) then
+      elseif( comp.struc(1:12)  == 'honeycomb_zx' ) then
 !         cdir = epDirec(dir.z, dir.x, dir.y)  X:z Y:x Z:y 
          temp = epDirec(dirc.y, dirc.z, dirc.x)
          dirv = temp 
