@@ -44,33 +44,43 @@ c             compress if 2.030000E-5 etc to 2.03E-5
              call epcompBlank(temp, f1)
 
              temp = ' '
-             if(  Det.cmp(i).MaxPathL .le. 0.d0 
+             if(  Det.cmp(i).MaxPathL .le. 0.d0 .and.
+     *            Det.cmp(i).Modifier .eq. 0
      *              .and. Det.cmp(i).chno .eq. NotGiven ) then
                 write(temp, '(a6,1p,3g20.6)') ' 0 0 /', 
      *               Det.cmp(i).orgx,  Det.cmp(i).orgy,
      *               Det.cmp(i).orgz
-             elseif( Det.cmp(i).MaxPathL .gt. 0.d0 
+             elseif( Det.cmp(i).MaxPathL .gt. 0.d0 .and.
+     *            Det.cmp(i).Modifier .eq. 0
      *              .and. Det.cmp(i).chno .eq. NotGiven ) then
                 write(temp, '(1p,g15.5, a4,3g20.6)')
      *               Det.cmp(i).MaxPathL,  ' 0 /', 
      *               Det.cmp(i).orgx,  Det.cmp(i).orgy,
      *               Det.cmp(i).orgz
+             elseif( Det.cmp(i).MaxPathL .le. 0.d0 .and.
+     *            Det.cmp(i).Modifier > 0
+     *              .and. Det.cmp(i).chno .eq. NotGiven ) then
+                write(temp, '(a3,i6, a3,1p, 3g20.6)')
+     *                 ' 0 ',   Det.cmp(i).Modifier," / ",
+     *               Det.cmp(i).orgx,  Det.cmp(i).orgy,
+     *               Det.cmp(i).orgz
+
              elseif( Det.cmp(i).chno .eq. NotGiven) then
-                write(temp, '(1p,g15.5, a2,3g20.6)')
-     *               Det.cmp(i).MaxPathL,
+                write(temp, '(1p,g15.5, i6, a2,3g20.6)')
+     *               Det.cmp(i).MaxPathL, Det.cmp(i).Modifier,
      *               ' /', 
      *               Det.cmp(i).orgx,  Det.cmp(i).orgy,
      *               Det.cmp(i).orgz
              elseif( Det.cmp(i).chno .ne. NotGiven) then
                 if( Det.cmp(i).MaxPathL .le. 0.) then
-                   write(temp, '(a3, i9, a2,1p, 3g20.6)')
-     *                  ' 0 ',    
+                   write(temp, '(a3,i6, i9, a2,1p, 3g20.6)')
+     *                  ' 0 ',    Det.cmp(i).Modifier,
      *                  Det.cmp(i).chno, ' /',    
      *                  Det.cmp(i).orgx,  Det.cmp(i).orgy,
      *                  Det.cmp(i).orgz
                 else
-                   write(temp, '(1p,g15.5, i8, a2, 3g20.6)')
-     *                  Det.cmp(i).MaxPathL,
+                   write(temp, '(1p,g15.5,i6, i8, a2, 3g20.6)')
+     *                  Det.cmp(i).MaxPathL, Det.cmp(i).Modifier,
      *                  Det.cmp(i).chno,  ' /',
      *                  Det.cmp(i).orgx,  Det.cmp(i).orgy,
      *                  Det.cmp(i).orgz
@@ -308,15 +318,17 @@ c
        integer i
        integer uscl
 
-       character*8 epparaphrase, tempph
+       character(len=MAX_STRUCCHR)::  epparaphrase, tempph
        character*80 msg
+       character(len=MAX_STRUCCHR)::  basename
+       
+       call epGetBaseStrucName(comp.struc, basename)
 
-       if(comp.struc(1:3) .eq. 'box' .or.
-     *    comp.struc(1:3) .eq. 'cyl' .or.          
-     *    comp.struc(1:4) .eq. 'pipe' .or.          
-     *    comp.struc .eq. 'prism' .or.          
-     *    comp.struc(1:6) .eq. 'prism_' .or.          
-     *    comp.struc(1:6) .eq. 'sphere' ) then
+       if(basename == 'box' .or.
+     *    basename == 'cyl' .or.          
+     *    basename == 'pipe' .or.          
+     *    basename == 'prism' .or.          
+     *    basename == 'sphere' ) then
           do i = 1, comp.Nattributes
              loc(i) = i
           enddo
