@@ -1,3 +1,5 @@
+!  next is to incldue MATHLOUSY 
+#include "Zcondc.h"
 !           test prog. is  in Epics/prog/Test/ (./testRange.sh)
 !       memory allocation; to save it, use single precision
       module modepRange
@@ -40,11 +42,22 @@
       real(8),parameter:: gbeta1 =0.01d0 ! 
       real(8),parameter:: gbeta2 = 2.0d0 
       real(8),parameter:: dKE = 0.1d0     ! log10 step from Ex1 to Ex2        
-      real(8),parameter:: logKE1 = log10(KE1)  ! energy step is in log step
+#if defined (MATHLOUSY)
+
+      real(8),parameter:: logKE1 = -6.d0 ! energy step is in log step
+      real(8),parameter:: logKE2 = -3.d0
+      integer,parameter:: nGBbin=
+     *    (3.01029995663981195215d-1 - (-2) )/dKE+1
+
+#else    
+
+      real(8),parameter:: logKE1 = log10(KE1) ! energy step is in log step
       real(8),parameter:: logKE2 = log10(KE2)
-      integer,parameter:: nKEbin= ( logKE2- logKE1 )/dKE + 1
       integer,parameter:: nGBbin= (log10(gbeta2)- log10(gbeta1) )/dKE+1
 
+#endif
+
+      integer,parameter:: nKEbin= ( logKE2- logKE1 )/dKE + 1
       real(prec),save:: logKEtbl(nKEbin)   ! log10(KE)
       real(prec),save:: logGBetatbl(nGBbin)  ! 
       real(prec),save,allocatable:: logGamLen(:,:)  !  gamma length(cm) (log is false)
