@@ -1,46 +1,18 @@
 #include "ZsubstRec.h"
 #include "Zunionmap.h"
-c   How to manage:
-c Interaction length sampling
-c  1) when a particle is popped up in Epics (say, let it be
-c     popped.p)
-c      call ep2cosPtcl(popped.p)  
-c       This sets the particle info in a common area contained in
-c       Zepics2cos.h
-c  2) Smple the path for the interaction of the
-c     particle, inform the Media by
-c      call ep2cosCond(Aeff, Zeff).
-c         This sets TrackBefMov using info in Zepics2cos.h
-c         and also sets Target A and Z.
-c  3) call ciniSmplInL.  This initializes interaction length
-c                        sampling. (Cosmos Function)
-c
-c  4) call csampNEPIntL. This actually samples interaction length.
-c         We don't use Cosmos knock-on process (histrical reason), we
-c         add the knock process as the competing processes.
-c   From version 7. this is replaced by epsmpNEPIntL.
-c
-c -----------------
-c Interaction 
-c     Knock-on is managed within Epics
-c    Nuclear interaction:
-c      call ep2cosPtcl(cTrack). This sets current particle as
-c                               a Cosmos particle.
-c      call ep2cosCond2(ia, iz). sets A,Z, 
-c      call cinteNEP    This makes interaction
-c      call eppushPtcl.  push ptcle  into epics area.
-c
-c  
-c       ********************************************
-c
-c       interface routines between epics and cosmos
-c 
-c       ********************************************
-c
-c            one pass routine to set cosmos param.
-c
-c               make a cosmos particle.
+!       ********************************************
+!
+!       interface routines between epics and cosmos
+!       for hadronic interactons. see 
+!                    ReadmeNI
+!       ********************************************
+!
+!
+
        subroutine ep2cosPtcl(aPtclin)
+!          this is called when a ptcl is popped up from
+!          stack. (prog/Light/epLightStack.f)
+!          at this moment, it is kept as aPtcl here
        implicit none
 #include "Zepi2cos.h"
        record /ptcl/aPtclin
@@ -48,13 +20,12 @@ c               make a cosmos particle.
        aPtcl = aPtclin
 
        end
-c       *****************************
-c       subroutine ep2cosCond(tmass, zchg)
+!       *****************************
        subroutine ep2cosCond
         implicit none
 #include "Zepi2cos.h"
 #include "Zcode.h"
-cc       real*8 tmass, zchg 
+!c       real*8 tmass, zchg 
 #ifdef UNIONMAP
        TrackBefMove.p = aPtcl
 #else
@@ -65,24 +36,23 @@ cc       real*8 tmass, zchg
        TrackBefMove.p.subcode = aPtcl.subcode
 #endif
 
-c             This is not used in m.f.p calculation from v7.
-cc       TargetMassN = tmass
-cc       TargetAtomicN = zchg
-       FromEpics = .true.   !  don't use knock-on func in Cosmos
+!             This is not used in m.f.p calculation from v7.
+!c       TargetMassN = tmass
+!c       TargetAtomicN = zchg
+       FromEpics = .true.   !  no meaning now
        end
-c       ********************* reset some of the cond for Cosmos
+!       *********************
        subroutine ep2cosCondr
         implicit none
 #include "Zepi2cos.h"
-        FromEpics =.false.
+        FromEpics =.false.  ! no meaning now
         end
 
-c      **********************************
-       subroutine ep2cosCond2(ia, iz, xs)
+!      **********************************
+       subroutine ep2cosCond2
        implicit none
 #include "Zepi2cos.h"
-       integer ia, iz  ! input. target nucleon number and Z
-       real*8 xs  !  xs in mb on this target
+
 #ifdef  UNIONMAP
        MovedTrack.p = aPtcl
 #else
@@ -92,36 +62,18 @@ c      **********************************
        MovedTrack.p.code = aPtcl.code
        MovedTrack.p.subcode = aPtcl.subcode
 #endif
-c                 actually no track inf. needed
-       TargetNucleonNo = ia
-       TargetProtonNo =  iz
-       TargetXs = xs
        end
-      subroutine epInfoPhotoP(gpinfo)
-!           copy the info for how to treat photo-had.prog
-      implicit none
-#include "Ztrackp.h"
-      integer,intent(in):: gpinfo
-      HowPhotoP = gpinfo
-      end
-      subroutine epInfoPhitsJamXs(phitsinfo, jaminfo)
-!           copy the info for how to treat X-section in phits and  Jam.
-      implicit none
-#include "Ztrackp.h"
-      integer,intent(in):: phitsinfo, jaminfo
-      PhitsXs = phitsinfo
-      JamXs = jaminfo
-      end
-c     ***************************
+!     ***************************
       subroutine eppushPtcl(cTrack)
-c            push Cosmos made ptlcs in the stack area
+!            push Cosmos made ptlcs in the stack area
       implicit none
 #include "Zepi2cos.h"      
 #define PTCL
 #include "ZepTrack.h"
 #undef PTCL
-      record /epTrack/ cTrack  ! input. some track info is extracted
-                              ! from here. interacting parent
+      record /epTrack/ cTrack  ! input. projectile of the interacion
+                           ! some track info is extracted
+                           ! from here. 
 
       record /epTrack/ nTrack 
       
@@ -135,8 +87,6 @@ c            push Cosmos made ptlcs in the stack area
       nTrack.user = cTrack.user
       nTrack.cn = cTrack.cn
 
-      
-
       do i = 1, Nproduced
          p = Pwork(i).fm.p(4)**2 - Pwork(i).mass**2
          sump2 = Pwork(i).fm.p(1)**2
@@ -154,11 +104,11 @@ c            push Cosmos made ptlcs in the stack area
             nTrack.w.y = 0.
             nTrack.w.z = 1.
          else
-c            this may not be the same as p because, pi0<->pic
-c            k0<->kch exchange to conserve total charge in Cosmos
-c            ; because mass is changed. adjust it otherwise
-c            direction cos may become inconsistent and
-c            boundary error might happen
+!            this may not be the same as p because, pi0<->pic
+!            k0<->kch exchange to conserve total charge in Cosmos
+!            ; because mass is changed. adjust it otherwise
+!            direction cos may become inconsistent and
+!            boundary error might happen
             adj = sqrt(p/sump2)
             Pwork(i).fm.p(1) =Pwork(i).fm.p(1)* adj
             Pwork(i).fm.p(2) =Pwork(i).fm.p(2)* adj
@@ -177,7 +127,7 @@ c            boundary error might happen
       enddo
       end
 
-c         for ibm
+!         for ibm; probably obso.
       subroutine epsubptcl(inp, out)
       implicit none
 #include   "Zptcl.h"
@@ -185,10 +135,10 @@ c         for ibm
       out = inp
       end
 
-c           fix interaction type choosing the smallest path.
-c           This is a modified version of cfixProc in Cosmos.
-c           The difference is due to the atmosphere and other
-c           constant density material  
+!           fix interaction type choosing the smallest path.
+!           This is a modified version of cfixProc in Cosmos.
+!           The difference is due to the atmosphere and other
+!           constant density material  
       subroutine epfixProc(den, gramcm2, proc)
       implicit none
 #include  "Zglobalc.h"
@@ -196,18 +146,18 @@ c           constant density material
 #include  "Ztrackv.h"
       real*8  den     ! input.  denstiy g/cm^3
       real*8  gramcm2 ! output. path length in g/cm2
-      character*8  proc ! output. process id characters
-
+      character(*),intent(out):: proc ! output. process id characters
+                    ! <= 8 
       real*8 len, minlen
-c     
+!     
       integer i
-c     
+!     
       minlen = Infty
 
       do i = 1, NumberOfInte
          if(.not. IntInfArray(i).decay) then
-c              convert kg/m2 into length in m
-c            IntInfArray(i).length = IntInfArray(i).thickness*0.1/den/100.
+!              convert kg/m2 into length in m
+!            IntInfArray(i).length = IntInfArray(i).thickness*0.1/den/100.
             len = IntInfArray(i).thickness*0.001d0/den
          else
             len = IntInfArray(i).length
@@ -222,13 +172,13 @@ c            IntInfArray(i).length = IntInfArray(i).thickness*0.1/den/100.
 
       if(IntInfArray(ProcessNo).decay) then
          IntInfArray(ProcessNo).thickness =
-c     *     IntInfArray(ProcessNo).length*100. * den*10. ! cm g/cm3*10-> kg/m2
+!     *     IntInfArray(ProcessNo).length*100. * den*10. ! cm g/cm3*10-> kg/m2
      *      IntInfArray(ProcessNo).length*1000. * den   !  in kg/m2
       endif
       gramcm2 = IntInfArray(ProcessNo).thickness * 0.1   ! in g/cm2
       proc = IntInfArray(ProcessNo).process
       end
-c     *********************************************
+!     *********************************************
       subroutine epsampPtcl(aPtcl)
 #include "Zptcl.h"
       integer fin
@@ -238,12 +188,16 @@ c     *********************************************
       
 
       end
-c          dummy routine which will never used but is needed
-c          to bypass the problem of unresolved external ref.
+!          dummy routine which will never used but is needed
+!          to bypass the problem of unresolved external ref.
       subroutine chookTrace
       end
 
       subroutine epsmpNEPIntL(media)
+!             xmedia=>media is to avoid name                          
+!       collision of media  in modXsecMedia and                       
+!       media argument in the subroutine def. 
+      use modXsecMedia, xmedia=>media
       implicit none
 #include  "Zglobalc.h"
 #include  "Zcode.h"
@@ -255,47 +209,39 @@ c          to bypass the problem of unresolved external ref.
 #include  "Zevhnp.h"
 #include  "Zevhnv.h"
 #include  "Zcmuint.h"
-#include  "Zmedia.h"
-c     **************************************************
-c
-      record /epmedia/ media  ! input.
+!     **************************************************
+!
+      type(xsmedia),intent(inout):: media
 
       real*8 mfp,  xs, mass
 
-
-c        m.f.p (kg/m**2) = abn /xsec(mb)
-c        parameter (aira=14.5, abogn=6.02e23, abn=aira*1.e28/abogn)
-c      real*8 abogn, toabn
-c      parameter (abogn=6.02d23, toabn=1.d28/abogn)
       real*8 collkgram, u, length
 
 
-
-
       call cdecayLeng(TrackBefMove, length)
 
       if(length .ne. Infty) then
          call csetIntInf(length, .true., 'decay')
       endif
 
-      if( TrackBefMove.p.code .eq. kmuon) return   ! ****************
-
-      call epgetxs(ActiveMdl, TrackBefMove.p, media, xs, mfp)
-      if(xs == smallxs ) then
-         collkgram = Infty
-      elseif(xs == largexs) then
-         collkgram = 0.
-      else
-         call rndc(u)
-         collkgram = -mfp*log(u)
+      if( TrackBefMove.p.code /= kmuon)  then
+!         call epgetxs(ActiveMdl2, TrackBefMove.p, media, xs, mfp)
+         call cGetXsec(ActiveMdl2, TrackBefMove.p, media, xs, mfp)
+         if(xs == smallxs ) then
+            collkgram = Infty
+         elseif(xs == largexs) then
+            collkgram = 0.
+         else
+            call rndc(u)
+            collkgram = -mfp*log(u)
+         endif
+         call csetIntInf(collkgram, .false., 'coll')            
       endif
-
-      call csetIntInf(collkgram, .false., 'coll')            
       end
 
       subroutine epsaveFirstCol
-c        This is called only when the first nuclear interaction
-c        or decay to save the collision info.
+!        This is called only when the first nuclear interaction
+!        or decay to save the collision info.
       implicit none
 #include "Zepi2cos.h"      
 #include "ZepMaxdef.h"
